@@ -18,9 +18,9 @@
 #include "k3bcore.h"
 #include "k3b_i18n.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QEventLoop>
-#include <QtCore/QStringList>
+#include <QDebug>
+#include <QEventLoop>
+#include <QStringList>
 
 
 
