@@ -17,7 +17,7 @@
 
 #include "k3b_export.h"
 
-#include <KCoreAddons/KJob>
+#include <KJob>
 #include <QScopedPointer>
 
 namespace K3b {
@@ -31,12 +31,12 @@ class LIBK3B_EXPORT KJobBridge : public KJob
 
 public:
     explicit KJobBridge( Job& job );
-    virtual ~KJobBridge();
+    ~KJobBridge() override;
     
-    virtual void start();
+    void start() override;
     
 protected:
-    virtual bool doKill();
+    bool doKill() override;
     
 private Q_SLOTS:
     void slotFinished( bool success );
