@@ -23,9 +23,9 @@
 #include "k3bglobalsettings.h"
 #include "k3b_i18n.h"
 
-#include <KConfigCore/KConfig>
-#include <KIOCore/KIO/Global>
-#include <KIOCore/KIO/Job>
+#include <KConfig>
+#include <KIO/Global>
+#include <KIO/Job>
 
 #include <QDebug>
 #include <QString>
