@@ -22,8 +22,8 @@
 #include "k3bcore.h"
 #include "k3b_i18n.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QFile>
+#include <QDebug>
+#include <QFile>
 
 #include <unistd.h>
 
