@@ -17,8 +17,8 @@
 
 #include "k3b_export.h"
 
-#include <QtCore/QIODevice>
-#include <QtCore/QScopedPointer>
+#include <QIODevice>
+#include <QScopedPointer>
 
 namespace K3b {
 
@@ -27,18 +27,18 @@ namespace K3b {
     class LIBK3B_EXPORT AudioCdTrackReader : public QIODevice
     {
     public:
-        AudioCdTrackReader( AudioCdTrackSource& source, QObject* parent = 0 );
-        ~AudioCdTrackReader();
+        explicit AudioCdTrackReader( AudioCdTrackSource& source, QObject* parent = 0 );
+        ~AudioCdTrackReader() override;
 
-        virtual bool open( OpenMode mode );
-        virtual void close();
-        virtual bool isSequential() const;
-        virtual qint64 size() const;
-        virtual bool seek( qint64 pos );
+        bool open( OpenMode mode ) override;
+        void close() override;
+        bool isSequential() const override;
+        qint64 size() const override;
+        bool seek( qint64 pos ) override;
 
     protected:
-        virtual qint64 writeData( const char* data, qint64 len );
-        virtual qint64 readData( char* data, qint64 maxlen );
+        qint64 writeData( const char* data, qint64 len ) override;
+        qint64 readData( char* data, qint64 maxlen ) override;
 
     private:
         class Private;
