@@ -23,9 +23,9 @@
 #include "k3bwavefilewriter.h"
 #include "k3b_i18n.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QIODevice>
-#include <QtCore/QFile>
+#include <QDebug>
+#include <QIODevice>
+#include <QFile>
 
 #include <unistd.h>
 
