@@ -28,17 +28,17 @@ namespace K3b {
     {
     public:
         explicit RawAudioDataReader( RawAudioDataSource& source, QObject* parent = 0 );
-        ~RawAudioDataReader();
+        ~RawAudioDataReader() override;
 
-        virtual bool open( OpenMode mode );
-        virtual void close();
-        virtual bool isSequential() const;
-        virtual qint64 size() const;
-        virtual bool seek( qint64 pos );
+        bool open( OpenMode mode ) override;
+        void close() override;
+        bool isSequential() const override;
+        qint64 size() const override;
+        bool seek( qint64 pos ) override;
 
     protected:
-        virtual qint64 writeData( const char* data, qint64 len );
-        virtual qint64 readData( char* data, qint64 maxlen );
+        qint64 writeData( const char* data, qint64 len ) override;
+        qint64 readData( char* data, qint64 maxlen ) override;
 
     private:
         class Private;
