@@ -24,7 +24,7 @@
 #include "k3bisoimager.h"
 #include "k3b_i18n.h"
 
-#include <KIOCore/KIO/Global>
+#include <KIO/Global>
 
 #include <QDebug>
 #include <QDir>
