@@ -23,8 +23,8 @@
 #include "k3bglobals.h"
 #include "k3b_i18n.h"
 
-#include <KConfigCore/KConfig>
-#include <KWidgetsAddons/KMessageBox>
+#include <KConfig>
+#include <KMessageBox>
 
 
 
