@@ -24,10 +24,10 @@ namespace K3b {
     class LIBK3B_EXPORT CdTextValidator : public Latin1Validator
     {
     public:
-        CdTextValidator(QObject *parent = 0);
-        ~CdTextValidator();
+        explicit CdTextValidator(QObject *parent = 0);
+        ~CdTextValidator() override;
 
-        State validate( QString& input, int& pos ) const;
+        State validate( QString& input, int& pos ) const override;
     };
 }
 
