@@ -16,7 +16,7 @@
 #define _K3B_DIR_SIZE_JOB_H_
 
 #include "k3bthreadjob.h"
-#include <KIOCore/KIO/Global>
+#include <KIO/Global>
 #include <QUrl>
 
 #include "k3b_export.h"
@@ -35,7 +35,7 @@ namespace K3b {
 
     public:
         explicit DirSizeJob( QObject* parent = 0 );
-        ~DirSizeJob();
+        ~DirSizeJob() override;
 
         KIO::filesize_t totalSize() const;
 
@@ -61,7 +61,7 @@ namespace K3b {
         void setFollowSymlinks( bool );
 
     private:
-        bool run();
+        bool run() override;
         bool countDir( const QString& dir );
         bool countFiles( const QStringList& l, const QString& dir );
 
