@@ -17,7 +17,7 @@
 
 #include "k3b_export.h"
 
-#include <QtCore/QString>
+#include <QString>
 
 namespace K3b {
     namespace VideoDVD
