@@ -23,8 +23,8 @@
 #include "k3bexternalbinmanager.h"
 #include "k3bplugin_i18n.h"
 
-#include <KConfigCore/KConfig>
-#include <KConfigCore/KSharedConfig>
+#include <KConfig>
+#include <KSharedConfig>
 
 #include <QDebug>
 #include <QFile>
@@ -45,7 +45,7 @@ public:
         : K3b::ExternalProgram( "sox" ) {
     }
 
-    bool scan( const QString& p ) {
+    bool scan( const QString& p ) override {
         if( p.isEmpty() )
             return false;
 
