@@ -28,8 +28,8 @@
 #include "k3bcddb.h"
 #include "k3bplugin_i18n.h"
 
-#include <KConfigCore/KConfig>
-#include <KWidgetsAddons/KMessageBox>
+#include <KConfig>
+#include <KMessageBox>
 
 #include <QDebug>
 #include <QString>
