@@ -13,11 +13,11 @@
  * See the file "COPYING" for the exact licensing terms.
  */
 
-#ifndef _K3B_DEBUG_OUTPUT_CACHE_H_
-#define _K3B_DEBUG_OUTPUT_CACHE_H_
+#ifndef _K3B_DEBUGGING_OUTPUT_CACHE_H_
+#define _K3B_DEBUGGING_OUTPUT_CACHE_H_
 
-#include <QtCore/QMap>
-#include <QtCore/QString>
+#include <QMap>
+#include <QString>
 
 
 namespace K3b {
