@@ -15,7 +15,7 @@
 #ifndef _K3B_DEVICE_DELEGATE_H_
 #define _K3B_DEVICE_DELEGATE_H_
 
-#include <KIOWidgets/KFileItemDelegate>
+#include <KFileItemDelegate>
 
 namespace K3b {
     class DeviceDelegate : public KFileItemDelegate
@@ -24,10 +24,10 @@ namespace K3b {
 
     public:
         explicit DeviceDelegate( QObject* parent );
-        ~DeviceDelegate();
+        ~DeviceDelegate() override;
 
-        QSize sizeHint( const QStyleOptionViewItem& option, const QModelIndex& index ) const;
-        void paint( QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index ) const;
+        QSize sizeHint( const QStyleOptionViewItem& option, const QModelIndex& index ) const override;
+        void paint( QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index ) const override;
     };
 }
 
