@@ -101,7 +101,7 @@ void K3b::ThemedHeader::init()
     m_rightLabel->setAutoFillBackground( true );
 
     QHBoxLayout* layout = new QHBoxLayout( this );
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing( 0 );
     layout->addWidget( m_leftLabel );
     layout->addWidget( m_titleLabel );
