@@ -15,7 +15,7 @@
 #ifndef _K3B_URL_NAVIGATOR_H_
 #define _K3B_URL_NAVIGATOR_H_
 
-#include <KIOFileWidgets/KUrlNavigator>
+#include <KUrlNavigator>
 #include <QUrl>
 
 namespace K3b {
@@ -29,7 +29,7 @@ namespace K3b {
 
     public:
         explicit UrlNavigator( KFilePlacesModel* model, QWidget* parent = 0 );
-        ~UrlNavigator();
+        ~UrlNavigator() override;
 
     public Q_SLOTS:
         void setDevice( K3b::Device::Device* );
