@@ -346,7 +346,6 @@ QModelIndex ExternalBinPermissionModel::buddy( const QModelIndex& index ) const
         return index;
 }
 
-#ifdef ENABLE_PERMISSION_HELPER
 void ExternalBinPermissionModel::setBurningGroup( const QString& burningGroup )
 {
     if( burningGroup != d->burningGroup ) {
@@ -366,7 +365,6 @@ void ExternalBinPermissionModel::setBurningGroup( const QString& burningGroup )
         endResetModel();
     }
 }
-#endif
 
 void ExternalBinPermissionModel::update()
 {
