@@ -19,7 +19,7 @@
 #include "k3baudiotrack.h"
 #include "k3baudiotrackreader.h"
 
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 
 
 class K3b::MusicBrainzTrackLookupJob::Private
