@@ -37,19 +37,19 @@ public:
      * @todo saving not completely implemented (fixed temporary file)
      */
     KoZipStore( QWidget* window, const QUrl& _url, const QString & _filename, Mode _mode, const QByteArray & appIdentification );
-    ~KoZipStore();
+    ~KoZipStore() override;
 
-    virtual qint64 write( const char* _data, qint64 _len );
+    qint64 write( const char* _data, qint64 _len ) override;
 protected:
     virtual bool initZipStore( Mode _mode, const QByteArray& appIdentification );
-    virtual bool doFinalize();
-    virtual bool openWrite( const QString& name );
-    virtual bool openRead( const QString& name );
-    virtual bool closeWrite();
-    virtual bool closeRead() { return true; }
-    virtual bool enterRelativeDirectory( const QString& dirName );
-    virtual bool enterAbsoluteDirectory( const QString& path );
-    virtual bool fileExists( const QString& absPath ) const;
+    bool doFinalize() override;
+    bool openWrite( const QString& name ) override;
+    bool openRead( const QString& name ) override;
+    bool closeWrite() override;
+    bool closeRead() override { return true; }
+    bool enterRelativeDirectory( const QString& dirName ) override;
+    bool enterAbsoluteDirectory( const QString& path ) override;
+    bool fileExists( const QString& absPath ) const override;
 
     /// The archive
     KZip * m_pZip;
