@@ -21,7 +21,7 @@
 #include <QApplication>
 #include <QStyle>
 #include <QStyleOptionButton>
-#include <QStyleOptionViewItemV4>
+#include <QStyleOptionViewItem>
 
 namespace K3b {
     
@@ -46,7 +46,7 @@ void VideoDVDTitleDelegate::paint( QPainter* painter, const QStyleOptionViewItem
     painter->save();
     
     QStyle& style = *QApplication::style();
-    QStyleOptionViewItemV4 option = opt;
+    QStyleOptionViewItem option = opt;
     initStyleOption( &option, index );
     style.drawControl( QStyle::CE_ItemViewItem, &option, painter );
     
@@ -203,13 +203,11 @@ void VideoDVDTitleDelegate::initStyleOption( QStyleOptionViewItem* option, const
 {
     if( index.isValid() && index.column() == VideoDVDTitleModel::TitleColumn )
     {
-        if( QStyleOptionViewItemV4 *v4 = qstyleoption_cast<QStyleOptionViewItemV4 *>(option) ) {
-            v4->index = index;
-            QVariant value = index.data( Qt::CheckStateRole );
-            if( value.isValid() && !value.isNull() ) {
-                v4->features |= QStyleOptionViewItemV2::HasCheckIndicator;
-                v4->checkState = static_cast<Qt::CheckState>( value.toInt() );
-            }
+        option->index = index;
+        QVariant value = index.data( Qt::CheckStateRole );
+        if( value.isValid() && !value.isNull() ) {
+            option->features |= QStyleOptionViewItem::HasCheckIndicator;
+            option->checkState = static_cast<Qt::CheckState>( value.toInt() );
         }
     }
 }
